==> bibledit-0.5.tar.gz: bibledit-0.5/src/dialogstylesheets.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGSTYLESHEETS_H
#define INCLUDED_DIALOGSTYLESHEETS_H

#include <gtk/gtk.h>
#include "configuration.h"


class StylesheetsDialog
{
public:
  StylesheetsDialog (int dummy);
  virtual ~StylesheetsDialog ();
  virtual int run();
  virtual void on_new ();
  virtual void on_edit ();
  virtual void on_delete ();
protected:
  GtkWidget *stylesheetsdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *combo1;
  GList *combo1_items;
  GtkWidget *combo_entry1;
  GtkWidget *hbox1;
  GtkWidget *newbutton;
  GtkWidget *propertiesbutton;
  GtkWidget *deletebutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *closebutton1;
  virtual void fillcombo (const string & active_stylesheet);
};


#endif

==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogstylesheets.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGSTYLESHEETS_H
#define INCLUDED_DIALOGSTYLESHEETS_H


#include <gtk/gtk.h>
#include "configuration.h"


class StylesheetsDialog
{
public:
  StylesheetsDialog (Configuration * configuration);
  virtual ~ StylesheetsDialog ();
  virtual int run ();
protected:
  Configuration * myconfig;
private:
  GtkWidget *stylesheetsdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *combo1;
  GtkWidget *combo_entry1;
  GtkWidget *hbox1;
  GtkWidget *newbutton;
  GtkWidget *propertiesbutton;
  GtkWidget *deletebutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *closebutton1;
  static void on_newbutton_clicked (GtkButton *button, gpointer user_data);
  virtual void on_new ();
  static void on_propertiesbutton_clicked (GtkButton *button, gpointer user_data);
  virtual void on_properties ();
  static void on_deletebutton_clicked (GtkButton *button, gpointer user_data);
  virtual void on_delete ();
  virtual void set_gui (const string& select);
};


#endif
